Titanium.include( 'database.js' );
Titanium.include( '/functions/images.js' );
Titanium.include( '/classes/forms.class.js' );
Titanium.include( '/classes/saves.class.js' );
Titanium.include( '/classes/topbar.class.js' );
Titanium.include( '/classes/user.class.js' );

// Mostramos el TopBar
new topBar({ showSearchButton:false }).show();

// Obtenemos la cuenta de usuario
var aUser = Titanium.App.User;

// Cálculo de tamaños //

var nWidth = Titanium.Platform.displayCaps.platformWidth;
var nHeight = Titanium.Platform.displayCaps.platformHeight;

// Calculamos el ancho y alto según la densidad
if( Titanium.Platform.osname == 'android' )
{
	// Ancho y alto según densidad
	nWidth = ( nWidth / ( Titanium.Platform.displayCaps.dpi / 160 ) );
	nHeight = ( nHeight / ( Titanium.Platform.displayCaps.dpi / 160 ) );
}

// Valores por defecto
var sEmail = (Titanium.App.isSimulator ? 'aerojimenez@hotmail.com' : '');
var sPassword = (Titanium.App.isSimulator ? 'david' : '');

// Bloque de información //

// Creamos el contenedor scroll
var sContent = Titanium.UI.createScrollView({ left:0, right:0, top:Titanium.App.top, bottom:Titanium.App.bottom, backgroundColor:'transparent', contentWidth:'auto', contentHeight:'auto', layout:'vertical', showVerticalScrollIndicator:true });
Titanium.UI.currentWindow.add( sContent );

// Creamos la vista para el bloque
var vInformation = Titanium.UI.createView({ left:nWidth * 0.05312, right:nWidth * 0.05312, top:nWidth * 0.05312, height:nHeight * 0.1708, backgroundImage:getImage( 'account_title.png' ), borderRadius:4 });
// Creamos la imágen izquierda
var iImage =  Titanium.UI.createImageView({ image:getImage( 'account_login_on.png' ), width:nWidth * 0.08437, height:nWidth * 0.08437, left:nWidth * 0.03125, top:nWidth * 0.03125, backgroundColor:'transparent', hires:true });
vInformation.add( iImage );
// Creamos el label del titulo
var lTitle = Titanium.UI.createLabel({ text:getLocatedString( 'window_login' ), font:{ fontName:'Helvetica Neue', fontSize:nWidth * 0.05625, fontWeight:'bold' }, color:'#000000', top:iImage.left, left:(iImage.left * 2) + iImage.width, height:vInformation.height / 4 });
vInformation.add( lTitle );
// Creamos el label de descripción
var lDescription = Titanium.UI.createLabel({ text:getLocatedString( 'message_window_login' ), font:{ fontName:'Helvetica Neue', fontSize:nWidth * 0.03615, fontWeight:'regular' }, color:'#000000', top:lTitle.top + lTitle.height, left:(iImage.left * 2) + iImage.width, right:(iImage.left * 2) + iImage.width, height:(vInformation.height / 3) * 2 });
vInformation.add( lDescription );
sContent.add( vInformation );

// Login //

// Clase para el formulario
var aForm = new form( sContent, vInformation.top + vInformation.height );

// Creamos todos los campos
var tEmail = aForm.addField({ name:'E-mail', hintText:'tu@email.com', keyboardType:Titanium.UI.KEYBOARD_EMAIL, defaultValue:sEmail }, { required:true, regex:/^([A-Za-z0-9_\-\.])+\@([A-Za-z0-9_\-\.])+\.([A-Za-z]{2,4})$/ });
var tPassword = aForm.addField({ name:getLocatedString( 'text_password' ), hintText:'********', passwordMask:true, defaultValue:sPassword }, { required:true });

// Botón para aceptar
var bLogin = Titanium.UI.createButton({ title:getLocatedString( 'text_enter' ), top:vInformation.left, width:nWidth * 0.7156, height:nHeight * 0.075, backgroundImage:getImage( 'button_account_enter.png' ) });
sContent.add( bLogin );

// Evento cuando hacemos click en Enviar
bLogin.addEventListener( 'click', function(e)
{
	// Validamos el formulario
	if( aForm.check() )
	{
		// Obtenemos el archivo del carrito
		var aFile = Titanium.Filesystem.getFile( Titanium.Filesystem.applicationDataDirectory, 'cart.txt' );

		// Hacemos login
		query({ query:'userLogin', data:{ email:tEmail.value, password:tPassword.value, cart:(aFile.exists() ? aFile.read().text : 'false') }, callback:function(aResult, aLoading)
		{
			// Si obtenemos un usuario negativo
			if( aResult['userid'] == -1 )
			{
				// Informamos
				Titanium.UI.createAlertDialog({ title:getLocatedString( 'text_message' ), message:getLocatedString( 'message_error_login' ).replace( '%s', tEmail.value ), buttonNames:['Aceptar'] }).show();

				return false;
			}

			// Establecemos los datos
			aUser.setUserid( aResult['userid'] );
			aUser.setEmail( tEmail.value );
			aUser.setUsername( aResult['username'] );
			aUser.setPassword( tPassword.value );

			// Marcamos al usuario como logueado
			aUser.setLogged( true );

			// Mostramos mensaje de bienvenida
			Titanium.UI.createAlertDialog({ title:getLocatedString( 'text_message' ), message:getLocatedString( 'text_welcome' ) + ' ' + aUser.getUsername() + '!', buttonNames:['Aceptar'] }).show();

			// Guardamos al usuario en la sesión
			Titanium.App.User = aUser;

			// Eliminamos el carrito local
			if( aFile.exists() )
				aFile.deleteFile();

			// Aumentamos el badge en Android
			if( Titanium.Platform.osname == 'android' )
			{
			}
			// Aumentamos el badge en iOS
			else
				Titanium.UI.currentTabGroup.tabs[2].badge = (aResult['cart'] > 0 ? aResult['cart'] : null);

			// Liberamos la ventana de carga
			if( aLoading != undefined )
				aLoading.hide();

			// Llamamos a la función para mostrar las opciones
			Titanium.App.fireEvent( 'myAccount', {} );

			// Cerramos la ventana
			Titanium.UI.currentWindow.close();
		}});
	}
});

// Botón para registrarse
var bRegister = Titanium.UI.createButton({ title:getLocatedString( 'text_create_new_account' ), color:'#ffffff', top:vInformation.left, width:nWidth * 0.7156, height:nHeight * 0.075, backgroundImage:getImage( 'button_account_register.png' ) });
sContent.add( bRegister );

// Evento cuando hacemos click en Registro
bRegister.addEventListener( 'click', function(e)
{
	// Abrimos la ventana de categorias
	var wWindow = Titanium.UI.createWindow({ title:getLocatedString( 'window_register' ), backgroundImage:getImage( 'background.png' ), url:'account_register.js', windowParent:Titanium.UI.currentWindow });

	// Abrimos la ventana
	openWindowInTab( wWindow );

	// Evento cuando se cierra la ventana
	wWindow.addEventListener( 'close', function(e)
	{
		// Si el usuario está logueado cerramos la ventana actual también
		if( Titanium.App.User.isLogged() )
			Titanium.UI.currentWindow.close();
	});
});