Titanium.include( 'database.js' );
Titanium.include( '/functions/app.js' );
Titanium.include( '/functions/array.js' );
Titanium.include( '/functions/css.js' );
Titanium.include( '/functions/currencies.js' );
Titanium.include( '/functions/images.js' );
Titanium.include( '/functions/location.js' );
Titanium.include( '/classes/saves.class.js' );
Titanium.include( '/classes/topbar.class.js' );

/* Variables globales */

// Variable que contendrá los productos
var aProducts = [];
// Tabla de productos
var tTable = undefined;
// Vista de botones de cashout
var vCashout = undefined;
// Label de información
var wInformation = undefined;
// Picker de cantidad
var vPicker = undefined;
var pPicker = undefined;
// Labels de precios
var aTotal = null;

// Variable de salvado de datos
var aSaves = new Saves( 'cart' );

// Forzamos el color de fondo
Titanium.UI.currentWindow.backgroundColor = '#ffffff';

/* Top Bar */

// Mostramos el TopBar
var aTopBar = new topBar({ backButton:false, showSearchButton:false, editButton:true });
aTopBar.show();

// Botón izquierdo para vaciar el carrito //

// Evento cuando hacemos click en el botón de vaciar
var emptyClick = function(e)
{
	// Si hay productos
	if( tTable != undefined )
	{
		// Ocultamos el picker
		if( vPicker != undefined )
			vPicker.animate( Titanium.UI.createAnimation({ bottom:-vPicker.height }) );

		// Creamos una ventana de diálogo con opciones para confirmar el vaciado
		var dDialog = Titanium.UI.createOptionDialog({ title:getLocatedString( 'message_empty_cart' ), options:[getLocatedString( 'text_yes' ), getLocatedString( 'text_no' )], destructive:1 });

		// Mostramos las opciones
		dDialog.show();

		// Evento que se lanza cuando se clica sobre alguna de las opciones del diálogo
		dDialog.addEventListener( 'click', function(e)
		{
			// Si clicamos en "Reintentar" probamos de nuevo la conexión
		    if( e.index == 0 )
		    {
				// Vaciamos el registro de productos
				aProducts = [];

				// Vaciamos el archivo
				aSaves.deleteFile();

				// Si estamos logueados vaciamos el carrito
				if( Titanium.App.User.isLogged() )
				{
					// Consulta para vaciar el carrito
					query({ query:'deleteBasket', data:{ userid:Titanium.App.User.userid, language:Titanium.App.idlanguage }, callback:function(aResult)
					{
						// Damos foco para refrescar
						Titanium.UI.currentWindow.fireEvent( 'focus' );
					}});
				}
				// Damos foco para refrescar
				else
					Titanium.UI.currentWindow.fireEvent( 'focus' );
		    }
		});
	}
}

// Mostramos el botón para vaciar
aTopBar.showTopButton( getLocatedString( 'text_empty' ), 'left', emptyClick );

// Carrito //

// Mostramos los datos cuando hacemos foco
Titanium.UI.currentWindow.addEventListener ( 'focus', function(e)
	{
		// Inicializamos el array de productos
		aProducts = [];

		// Ocultamos el picker
		if( vPicker != undefined )
			vPicker.animate( Titanium.UI.createAnimation({ bottom:-vPicker.height }) );

		// Si no estamos logueados obtenemos el carrito local
		if( ! Titanium.App.User.isLogged() )
		{
			// Obtenemos el archivo
			var aFile = Titanium.Filesystem.getFile( Titanium.Filesystem.applicationDataDirectory, Titanium.UI.currentWindow.type + '.txt' );

			// Obtenemos los productos
			query({ query:'getProductsByID', data:{ ids:(aFile.exists() ? aFile.read().text : '[]'), language:Titanium.App.idlanguage }, callback:productsList });
		}
		// Si estamos logueados obtenemos el carrito remoto
		else
		{
			// Obtenemos los productos
			query({ query:'getCartByUser', data:{ userid:Titanium.App.User.userid, language:Titanium.App.idlanguage }, callback:productsList });
		}
	}
);

function productsList(aResult)
{
	// Si obtenemos un resultado correcto
	if( aResult !== false )
	{
		// Si hay productos los mostramos
		if( aResult.length > 0 )
		{
			// Cálculo de tamaños //

			var nWidth = Titanium.Platform.displayCaps.platformWidth;
			var nHeight = Titanium.Platform.displayCaps.platformHeight;

			// Calculamos el ancho y alto según la densidad
			if( Titanium.Platform.osname == 'android' )
			{
				// Ancho y alto según densidad
				nWidth = ( nWidth / ( Titanium.Platform.displayCaps.dpi / 160 ) );
				nHeight = ( nHeight / ( Titanium.Platform.displayCaps.dpi / 160 ) );
			}

			// Productos //

			// Establecemos que la variable de productos contenga el resultado con los resultados formateados
			for( nCont = 0; nCont < aResult.length; nCont++ )
			{
				// Añadimos el registro al array de productos
				aProducts[nCont] = aResult[nCont];

				// Comprobamos si el producto está en oferta
				aProducts[nCont]['offer'] = (aResult[nCont].price_offer != null);

				// Si tenemos un precio de grupo lo cambiamos al precio
				if( aResult[nCont].price_group != null )
					aResult[nCont].price = aResult[nCont].price_group;

				// Calculo de precio //

				// Obtenemos el precio original y el precio en oferta
				fPrice = aResult[nCont].price;
				fPriceOffer = aResult[nCont].price_offer;

				// Guardamos los precios
				aProducts[nCont]['price'] = getPriceFormatted( (aProducts[nCont].offer ? fPriceOffer : fPrice), aResult[nCont].tax );
				aProducts[nCont]['price_offer'] = getPriceFormatted( (aProducts[nCont].offer ? fPrice : false), aResult[nCont].tax );
				aProducts[nCont]['price_float'] = parseFloat( (aProducts[nCont].offer ? fPriceOffer : fPrice) );
				aProducts[nCont]['cartquantity'] = (Titanium.App.User.isLogged() ? aResult[nCont].cartquantity : aSaves.cartGetQuantity( aProducts[nCont].idproduct ));
			}

			// Llamamos a la función para crear el listado de productos
			products( aProducts );
		}
		// Si no hay productos mostramos mensaje de información
		else
		{
			// Eliminamos la tabla de datos anterior
			if( tTable != undefined )
			{
				Titanium.UI.currentWindow.remove( tTable );
				tTable = undefined;
			}
			// Eliminamos la vista de cashout
			if( vCashout != undefined )
			{
				Titanium.UI.currentWindow.remove( vCashout );
				vCashout = undefined;
			}

			// Eliminamos los elementos sobrantes
			for( nCont = 0; nCont < Titanium.UI.currentWindow.children.length; nCont++ )
			{
				// Si tenemos la propiedad eRemove, quiere decir que quiere ser eliminado
				if( Titanium.UI.currentWindow.children[nCont].eremove )
					Titanium.UI.currentWindow.remove( Titanium.UI.currentWindow.children[nCont] );
			}

			// Mostramos el fondo vacio
			Titanium.UI.currentWindow.backgroundImage = getImage( 'empty.png' );

			// Contenedor de información
			wInformation = Titanium.UI.createView({ left:10, right:10, top:Titanium.App.top + hPer( 100 ), bottom:Titanium.App.bottom, layout:'vertical' });
			Titanium.UI.currentWindow.add( wInformation );
			// Creamos el label de información
			var lInformation = Titanium.UI.createLabel({ text:getLocatedString( 'message_no_cart' ), font:{ fontSize:wPer( 45 ), fontWeight:'bold' }, shadowOffset:{x:3, y:3}, textAlign:'center' });
			css( lInformation, 'products_empty_information' );
			wInformation.add( lInformation );
			// Creamos el label de información extra
			var lInformationExtra = Titanium.UI.createLabel({ text:getLocatedString( 'message_no_extra' ), font:{ fontSize:wPer( 45 ), fontWeight:'bold' }, shadowOffset:{x:3, y:3}, textAlign:'center' });
			css( lInformationExtra, 'products_empty_information_extra' );
			wInformation.add( lInformationExtra );
		}
	}
}

function products(aOrders)
{
	// Mensaje de carga //

	// Creamos el mensaje de carga
	if( tTable != undefined )
	{
		var aLoading = Titanium.UI.createActivityIndicator();

		if( Titanium.App.isAndroid )
			aLoading.message = 'Ordenando...';
		else
			 aLoading.style = Titanium.UI.iPhone.ActivityIndicatorStyle.PLAIN;
		Titanium.UI.currentWindow.add( aLoading );
		aLoading.show();
	}

	// Cálculo de tamaños //

	var nWidth = Titanium.Platform.displayCaps.platformWidth;
	var nHeight = Titanium.Platform.displayCaps.platformHeight;

	// Calculamos el ancho y alto según la densidad
	if( Titanium.Platform.osname == 'android' )
	{
		// Ancho y alto según densidad
		nWidth = ( nWidth / ( Titanium.Platform.displayCaps.dpi / 160 ) );
		nHeight = ( nHeight / ( Titanium.Platform.displayCaps.dpi / 160 ) );
	}

	var nChashoutSize = nHeight * 0.1875;
	var nRowSize = (nHeight - Titanium.App.topBarSize - Titanium.App.tabGroupSize - nChashoutSize) / 3;
	var nQuantitySize = nWidth * 0.0625;

	// Productos //

	// Eliminamos la tabla de datos anterior
	if( tTable != undefined )
	{
		Titanium.UI.currentWindow.remove( tTable );
		tTable = undefined;
	}
	// Eliminamos el mensaje de información anterior
	if( wInformation != undefined )
	{
		Titanium.UI.currentWindow.remove( wInformation );
		wInformation = undefined;
	}

	// Si hay productos los mostramos
	if( aOrders.length > 0 )
	{
		// Mostramos el fondo
		Titanium.UI.currentWindow.backgroundImage = getImage( 'background.png' );

		// Creamos la tabla para mostrar los productos
		tTable = Titanium.UI.createTableView({ top:Titanium.App.top, bottom:Titanium.App.bottom + nChashoutSize, backgroundColor:'#ffffff', allowsSelection:true, allowsSelectionDuringEditing:false, editable:true, editing:aTopBar.getEditing(), deleteButtonTitle:getLocatedString( 'button_delete' ), backgroundImage:getImage( 'background-cart.png' ), eremove:true });

		// Array de datos
		var aData = [];

		// Recorremos el resultado y lo añadimos a la tabla
		for( nCont = 0; nCont < aOrders.length; nCont++ )
		{
			// Creamos la fila
			var aRow = Titanium.UI.createTableViewRow({ index:nCont, id:aOrders[nCont].idproduct, text:aOrders[nCont].product, height:nRowSize, className:'cart', backgroundColor:(nCont % 2 == 0 ? '#fffcee' : '#fffcee'), selectionStyle:Titanium.UI.iPhone.TableViewCellSelectionStyle.NONE, borderColor:'#cccccc', hasChild:false });

			// Obtenemos la URL de la imagen
			var sImage = (aOrders[nCont].image != '' && aOrders[nCont].image != null ? Titanium.App.images + 'img/p/' + aOrders[nCont].image.split( '' ).join( '/' ) + '/' + aOrders[nCont].image + '-home.jpg' : '');
			// Creamos la imagen izquierda
			var iImage =  Titanium.UI.createImageView({ image:encodeURI( sImage ), width:nRowSize - 4, height:nRowSize - 4, top:2, left:2, backgroundColor:'transparent', hires:true });
			aRow.add( iImage );
			// Creamos la linea decorativa
			aRow.add( Titanium.UI.createView({ top:0, left:nRowSize, bottom:0, width:1, backgroundColor:'#cccccc' }) );
			// Creamos el label del titulo
			var lTitle = Titanium.UI.createLabel({ text:(aOrders[nCont].product.length > 23 ? aOrders[nCont].product.substr( 0, 20 ) + '...' : aOrders[nCont].product ), font:{ fontSize:nRowSize / 6, fontWeight:'bold' }, color:'#444444', top:0, left:nRowSize + 15, right:15, height:nRowSize / 2, textAlign:'left' });
			aRow.add( lTitle );
			// Creamos la vista superior
			var vTop = Titanium.UI.createView({ id:aOrders[nCont].idproduct, text:aOrders[nCont].product, left:0, right:0, top:0, bottom:0, backgroundColor:'transparent' });
			aRow.add( vTop );
			// Creamos los botones de cantidad -
			var lDown = Titanium.UI.createLabel({ index:nCont, id:aOrders[nCont].idproduct, text:'-', textAlign:'center', color:'#606060', left:lTitle.left, top:((nRowSize / 4) * 3) - (nQuantitySize / 2), width:nQuantitySize, height:nQuantitySize, backgroundColor:'#cdcdcd', borderRadius:3, zIndex:0 });
			aRow.add( lDown );
			// Creamos el label de cantidad
			var lQuantity = Titanium.UI.createLabel({ index:nCont, id:aOrders[nCont].idproduct, text:aOrders[nCont].cartquantity, textAlign:Titanium.UI.TEXT_ALIGNMENT_CENTER, font:{ fontSize:nWidth / 25, fontWeight:'regular' }, color:'#606060', left:lDown.left + lDown.width + 5, top:((nRowSize / 4) * 3) - ((nWidth * 0.09375) / 2), width:nWidth * 0.09375, height:nWidth * 0.09375, borderRadius:5, borderWidth:1, borderColor:'#9e9e9e', backgroundColor:'#ffffff' });
			aRow.add( lQuantity );
			// Creamos los botones de cantidad +
			var lUp = Titanium.UI.createLabel({ index:nCont, id:aOrders[nCont].idproduct, text:'+', textAlign:'center', color:'#606060', left:lQuantity.left + lQuantity.width + 5, top:lDown.top, width:nQuantitySize, height:nQuantitySize, backgroundColor:'#cdcdcd', borderRadius:3, zIndex:0 });
			aRow.add( lUp );
			// Añadimos el campo al label
			lUp.field = lQuantity;
			lDown.field = lQuantity;
			// Mostramos el precio
			var aPrice = showPrice( { price:aOrders[nCont].price, fontSize:nWidth * 0.078125, left:((nWidth - (lUp.left + lUp.width)) / 6) + (lUp.left + lUp.width), top:lQuantity.top, width:nWidth - (((nWidth - (lUp.left + lUp.width)) / 6) + (lUp.left + lUp.width)), height:nRowSize - lQuantity.top, offer:false } )
			aRow.add( aPrice );

			// Evento cuando hacemos click en un elemento de la lista
			vTop.addEventListener('click', function(e)
			{
				// Abrimos la ventana de detalle de producto
				var wProductDetail = Titanium.UI.createWindow({ id:e.source.id, title:e.source.text, backgroundColor:'#ffffff', url:'productdetail.js', windowParent:Titanium.UI.currentWindow });

				// Abrimos la ventana
				openWindow( wProductDetail );
			});

			// Evento cuando hacemos pulsamos sobre un botón de cantidad
			lUp.addEventListener('touchstart', function(e){ e.source.backgroundColor = '#b6b6b6'; });
			lDown.addEventListener('touchstart', function(e){ e.source.backgroundColor = '#b6b6b6'; });

			// Evento cuando hacemos levantamos el dedo de un botón de cantidad
			lUp.addEventListener('touchend', function(e){ e.source.backgroundColor = '#cdcdcd'; });
			lDown.addEventListener('touchend', function(e){ e.source.backgroundColor = '#cdcdcd'; });

			// Evento cuando hacemos click en un botón de cantidad
			lUp.addEventListener('click', function(e){ cartQuantity( e ) });
			lDown.addEventListener('click', function(e){ cartQuantity( e ) });

			// Función para añadir una cantidad al carrito
			function cartQuantity(e)
			{
				// Obtenemos la cantidad
				nQuantity = parseInt( e.source.field.text );
				// Obtenemos la cantidad a sumar
				nAdd = (e.source.text == '+' ? 1 : -1);

				// Si restamos y llegamos a 0 cancelamos
				if( e.source.text == '-' && nQuantity - 1 == 0 )
					return false;

				// Actualizamos el campo
				e.source.field.text = ( nQuantity + nAdd ).toString();

				// Guardamos en el carrito
				aSaves.cartSave({ idproduct:e.source.id, quantity:nAdd });

				// Actualizamos la cantidad del array de productos
				aProducts[e.source.index].cartquantity = e.source.field.text;

				// Mostramos el precio total
				showTotalPrice();
			}

			// Evento cuando hacemos click en el label de cantidad
			lQuantity.addEventListener('click', function(e)
			{
				// Cambiamos los colores a los bordes
				if( pPicker.field != undefined )
					pPicker.field.borderColor = '#9e9e9e';
				e.source.borderColor = '#f7b06b';

				// Seleccionamos el valor en el picker
				pPicker.setSelectedRow( 0, parseInt( e.source.text ) - 1 );

				// Mostramos el picker
				vPicker.animate( Titanium.UI.createAnimation({ bottom:0 }) );

				// Indicamos el label de cantidad al picker
				pPicker.field = e.source;
			});

			// Añadimos la fila a los datos
			aData.push( aRow );
		}

		// Añadimos los datos a la tabla
		tTable.setData( aData );

		// Pasamos al topBar la tabla para ser editada
		aTopBar.setTable( tTable );

		// Añadimos la tabla
		Titanium.UI.currentWindow.add( tTable );

		// Evento cuando eliminamos un elemento de la lista
		tTable.addEventListener('delete', function(e)
		{
			// Eliminamos el elemento seleccionado del fichero
			aSaves.deleteRecord({ id:e.rowData.id });

			// Damos foco para refrescar
			Titanium.UI.currentWindow.fireEvent( 'focus' );
		});

		// Barra de cashout //

		// Contenedor para la barra de cashout			
		vCashout = Titanium.UI.createView({ left:0, bottom:Titanium.App.bottom, width:nWidth, height:nChashoutSize, backgroundColor:Titanium.App.cashout_color, eremove:true });
		vCashout.add( Titanium.UI.createView({ left:0, top:0, width:nWidth, height:1, backgroundColor:Titanium.App.cashout_border_color }) );
		Titanium.UI.currentWindow.add( vCashout );
		// Label de total
		lTotal = Titanium.UI.createLabel({ text:'Total:', font:{ fontSize:nWidth / 20, fontWeight:'bold' }, color:'#ffffff', left:10, top:vCashout.height / 4, width:'auto', height:'auto' });
		vCashout.add( lTotal );
		// Precio total
		aTotal = showPrice( { price:'00,00', fontSize:nWidth * 0.078125, color:'#ffffff', left:10, top:(nChashoutSize / 2), width:nWidth, height:nChashoutSize / 2, offer:false } )
		vCashout.add( aTotal );
		showTotalPrice();
		// Botón de comprar
		bBuy = Titanium.UI.createLabel({ text:getLocatedString( 'pd_buy' ), textAlign:Titanium.UI.TEXT_ALIGNMENT_CENTER, font:{ fontFamily:'Helvetica Neue', fontSize:nWidth * 0.0625, fontWeight:'bold' }, color:'#ffffff', backgroundImage:getImage( 'button_buy.png' ), right:10, width:((nWidth / 3.3) * 2) - 10, height:nChashoutSize / 1.66, orders:aOrders });
		vCashout.add( bBuy );

		// Evento cuando hacemos click en comprar
		bBuy.addEventListener('click', function(e)
		{
			// Si no estamos logueados tendremos la opción
			if( ! Titanium.App.User.isLogged() )
			{
				// Creamos una ventana de diálogo con opciones para reintentar o salir
				var dDialog = Titanium.UI.createOptionDialog({ title:getLocatedString( 'message_init_session' ), options:[getLocatedString( 'text_login' ), getLocatedString( 'text_cancel' )], destructive:1 });

				// Mostramos las opciones
				dDialog.show();

				// Evento que se lanza cuando se clica sobre alguna de las opciones del diálogo
				dDialog.addEventListener( 'click', function(e)
				{
					// Ventana de login
				    if( e.index == 0 )
				    {
						// Abrimos la ventana de categorias
						var wWindow = Titanium.UI.createWindow({ title:getLocatedString( 'text_data_access' ), backgroundImage:getImage( 'background.png' ), url:'account_login.js', windowParent:Titanium.UI.currentWindow });

						// Abrimos la ventana
						openWindowInTab( wWindow );
				    }
				});
			}

			// Si hemos iniciado sesión abrimos el explorador para el checkout
			if( Titanium.App.User.isLogged() )
			{
				// Variable de stock
				var sStock = '';

				// Comprobamos que tenemos stock de todos los productos
				for( nCont = 0; nCont < e.source.orders.length; nCont++ )
				{
					// Si tenemos un producto sin stock
					if( parseInt( e.source.orders[nCont].quantity ) < parseInt( e.source.orders[nCont].cartquantity ) )
					{
						// Marcamos sin stock
						sStock = sStock + '\n- ' + e.source.orders[nCont].product;
					}
				}

				// Si tenemos stock
				if( sStock == '' )
				{
					// Mostramos el checkout
					var wWeb = Titanium.UI.createWindow({ title:'Comprar', link:Titanium.App.server + 'autenticacion?from=appcommerce&email=' + Titanium.App.User.getEmail() + '&password=' + Titanium.App.User.getPassword(), backgroundColor:'#000000', url:'web.js', windowParent:Titanium.UI.currentWindow });
					openWindow( wWeb );

					// Evento que se lanza al cerrar la ventana de checkout
					wWeb.addEventListener('close', function(e)
					{
						// Damos foco para refrescar
						Titanium.UI.currentWindow.fireEvent( 'focus' );
					});
				}
				// Si no tenemos stock, informamos
				else
					Titanium.UI.createAlertDialog({ title:getLocatedString( 'text_message' ), message:getLocatedString( 'message_no_stock' ) + sStock, buttonNames:['Aceptar'] }).show();
			}
		});

		// Picker de cantidad //

		// Creamos la vista para el picker
		if( Titanium.Platform.osname == 'android' ) vPicker = Titanium.UI.createView({ height:163, bottom:-163, backgroundColor:'#000000' });
		else if( Titanium.Platform.osname == 'ipad' ) vPicker = Titanium.UI.createView({ height:480 * 0.5416, bottom:-(480 * 0.5416), backgroundColor:'transparent' });
		else vPicker = Titanium.UI.createView({ height:nHeight * 0.5416, bottom:-(nHeight * 0.5416), backgroundColor:'transparent' });
		Titanium.UI.currentWindow.add( vPicker );
		// Creamos la barra de tareas
		var vToolBar = Titanium.UI.createView({ top:0, height:nHeight * 0.0916, backgroundColor:'#000000', opacity:0.3 });
		vPicker.add( Titanium.UI.createView({ top:0, height:1, backgroundColor:'#343434' }) );
		vPicker.add( Titanium.UI.createView({ top:1, height:1, backgroundColor:'#b8b8b8' }) );
		vPicker.add( vToolBar );
		// Creamos el botón de OK
		var bPickerOK = showButton( 'OK', { right:5, top:5 }, function(e)
			{
				// Ocultamos el picker
				vPicker.animate( Titanium.UI.createAnimation({ bottom:-vPicker.height }) );
			}
		);
		vPicker.add( bPickerOK );
		// Creamos el picker de cantidad
		pPicker = Titanium.UI.createPicker({ bottom:0, selectionIndicator:true, useSpinner:true });
		// Rellenamos los datos
		aPickerData = [];
		for( nCont = 1; nCont <= 100; nCont++ )
			aPickerData.push( Titanium.UI.createPickerRow({ title:nCont.toString() }) );
		pPicker.add( aPickerData );
		vPicker.add( pPicker );

		// Evento cuando cambiamos de valor con el picker
		pPicker.addEventListener('change', function(e)
		{
			// Obtenemos la cantidad a sumar
			nAdd = parseInt( e.selectedValue[0] ) - parseInt( e.source.field.text );

			if( nAdd != 0 )
			{
				// Actualizamos el campo
				e.source.field.text = e.selectedValue[0];

				// Guardamos en el carrito
				aSaves.cartSave({ idproduct:e.source.field.id, quantity:nAdd });

				// Actualizamos la cantidad del array de productos
				aProducts[e.source.field.index].cartquantity = e.source.field.text;

				// Mostramos el precio total
				showTotalPrice();
			}
		});

		// Pasamos al topBar el picker
		aTopBar.setPicker( vPicker );
	}

	// Liberamos la ventana de carga
	if( aLoading != undefined )
	{
		aLoading.hide();
		Titanium.UI.currentWindow.remove( aLoading );
	}
}

function showTotalPrice()
{
	// Cálculo de tamaños //

	var nWidth = Titanium.Platform.displayCaps.platformWidth;
	var nHeight = Titanium.Platform.displayCaps.platformHeight;

	// Calculamos el ancho y alto según la densidad
	if( Titanium.Platform.osname == 'android' )
	{
		// Ancho y alto según densidad
		nWidth = ( nWidth / ( Titanium.Platform.displayCaps.dpi / 160 ) );
		nHeight = ( nHeight / ( Titanium.Platform.displayCaps.dpi / 160 ) );
	}

	// Variables
	fTotal = 0;
	nTax = null;

	// Recorremos los productos
	for( nCont = 0; nCont < aProducts.length; nCont++ )
	{
		// Obtenemos el precio
		fPrice = aProducts[nCont].price_float;
		// Multiplicamos la cantidad del carrito
		fPrice = fPrice * aProducts[nCont].cartquantity;
		// Sumamos al total
		fTotal = fTotal + fPrice;
		// Obtenemos el tax
		nTax = aProducts[nCont].tax;
	}

	// Formateamos el resultado
	fTotal = getPriceFormatted( fTotal, nTax )

	// Pintamos el total //

	// Separamos la parte entera de la decimal del precio
	aAux = fTotal.split( ',' );

	// Obtenemos la parte entera
	nEntire = aAux[0];
	// Obtenemos la parte decimal
	nDecimal = ',' + aAux[1] + '€';

	// Mostramos el precio
	aTotal.entire.text = nEntire;
	aTotal.decimal.text = nDecimal;
}