Titanium.include( '/functions/location.js' );

/**
 * Función query para hacer consultas a la Base de Datos. Se especifica la consulta que se hará y los parámetros que queremos enviar.
 *
 * Parámetros:
 * 	function callback
 * 
 */
var query = function(aParams)
{
	// Chequeamos la conexión a Internet
	online({ callback:function()
		{
			// Mensaje de carga //

			// Si tenemos indicada que se muestre el mensaje de carga
			if( ( aParams.hasOwnProperty( 'showLoading' ) && aParams.showLoading ) || ! aParams.hasOwnProperty( 'showLoading' ) )
			{
				// Obtenemos el mensaje de carga
				if( aParams.query.substr( 0, 3 ) == 'get' ) sMessage = getLocatedString( 'loading_get' );
				else if( aParams.query.substr( 0, 6 ) == 'insert' ) sMessage = getLocatedString( 'loading_insert' );
				else if( aParams.query.substr( 0, 6 ) == 'delete' ) sMessage = getLocatedString( 'loading_delete' );
				else sMessage = getLocatedString( 'loading_loading' );

				// Creamos el mensaje de carga y lo mostramos
				var aLoading = Titanium.UI.createActivityIndicator({ message:(Titanium.App.isAndroid ? sMessage : '') });
				if( ! Titanium.App.isAndroid )
					 aLoading.style = Titanium.UI.iPhone.ActivityIndicatorStyle.PLAIN;
				Titanium.UI.currentWindow.add( aLoading );
				aLoading.show();
			}

			// Petición HTTP //

			// Creamos el HTTPCliente
		    var hClient = Titanium.Network.createHTTPClient({ timeout:5000 });

			// Abrimos la URL
		    hClient.open( 'POST', Titanium.App.datalinker );

			// Establecemos el usuario y contraseña
		    hClient.setRequestHeader( 'Authorization', 'Basic ' + Titanium.Utils.base64encode( Titanium.App.username + ':' + Titanium.App.password ) );

			// Enviamos la petición HTTP //

			// Si no enviamos parámetros creamos la variable data
			if( ! aParams.hasOwnProperty( 'data' ) )
				aParams.data = {};

			// Añadimos la query a los datos
			aParams.data['query'] = aParams.query;

			// Realizamos la petición HTTP
			hClient.send( aParams.data );

			// Evento que se lanza cuando la petición se complete
		    hClient.onload = function()
		    {
		    	// Si obtenemos una respuesta
		    	if( this.responseText != false && this.responseText != 'false' )
		    	{
			    	// Si tenemos la propiedad callback, que será una función que se llamará automáticamente  
					if( aParams.hasOwnProperty( 'callback' ) && typeof aParams.callback == 'function' )
					{
						// Titanium.UI.createAlertDialog({ title:'Mensaje', message:this.responseText, buttonNames:['Aceptar'] }).show();

						// Lanzamos la función callback
						aParams.callback( eval( '(' + this.responseText + ')' ), aLoading );
					}
				}
				// Si no hemos obtenido un resultado correcto lanzamos el evento de error
				else
					hClient.onerror();

				// Liberamos la ventana de carga
				if( aLoading != undefined )
				{
					aLoading.hide();
			        Titanium.UI.currentWindow.remove( aLoading );
				}
		    };

			// Evento que se lanzará cuando la petición de error
		    hClient.onerror = function()
		    {
				// Creamos una ventana de diálogo con opciones para reintentar
				var dDialog = Titanium.UI.createAlertDialog({ title:'Error', message:getLocatedString( 'database_error' ), buttonNames:[getLocatedString( 'database_retry' )] });

				// Mostramos las opciones
				dDialog.show();

				// Evento que se lanza cuando se clica sobre alguna de las opciones del diálogo
				dDialog.addEventListener( 'click', function(e)
				{
					// Si clicamos en "Reintentar" probamos de nuevo a enviar los datos
				    if( e.index == 0 )
				    {
				    	// Abrimos la URL
		    			hClient.open( 'POST', Titanium.App.datalinker );

						// Establecemos el usuario y contraseña
					    hClient.setRequestHeader( 'Authorization', 'Basic ' + Titanium.Utils.base64encode( Titanium.App.username + ':' + Titanium.App.password ) );

						// Realizamos la petición HTTP
				    	hClient.send( aParams.data );
				    }
				});

				// Liberamos la ventana de carga
				if( aLoading != undefined )
				{
					aLoading.hide();
			        Titanium.UI.currentWindow.remove( aLoading );
				}
		    };
		}
	});
};

/**
 * Función online para comprobar si hay conexión a Internet. Dará la posibilidad de reintentar la comprobación tantas veces se quiera.
 */
var online = function(aParams)
{
	// Si NO tenemos conexión a Internet
	if( ! Titanium.Network.online )
	{
		// Creamos una ventana de diálogo con opciones para reintentar
		var dDialog = Titanium.UI.createAlertDialog({ title:'Error', message:getLocatedString( 'database_error' ), buttonNames:[getLocatedString( 'database_retry' )] });

		// Mostramos las opciones
		dDialog.show();

		// Evento que se lanza cuando se clica sobre alguna de las opciones del diálogo
		dDialog.addEventListener( 'click', function(e)
		{
			// Si clicamos en "Reintentar" probamos de nuevo la conexión
		    if( e.index == 0 )
		    	online( aParams );
		});
	}
	// Si SI tenemos conexión a Internet
	else
	{
		// Si tenemos una función de callback
		if( aParams.hasOwnProperty( 'callback' ) )
			if( typeof aParams.callback == 'function' )
				aParams.callback();
	}
}