Titanium.include( '/functions/images.js' );

function getStockImage(nQuantity)
{
	// Si el stock es mayor o igual a 3
	if( nQuantity >= 3 )
		return getImage( 'stock_on.png' );
	// Si el stock está entre 3 y 1
	else if( nQuantity < 3 && nQuantity >= 1 )
		return getImage( 'stock_medium.png' );
	// Si el stock es menor de 1
	else if( nQuantity < 1 )
		return getImage( 'stock_off.png' );
}

function showAlert(sMessage)
{
	// Mensaje informativo
	
	// En Android
	if( Titanium.Platform.osname == 'android' )
	{
		// Creamos y mostramos la notificación
		var nMessage = Ti.UI.createNotification({ message:sMessage, duration:Ti.UI.NOTIFICATION_DURATION_SHORT });
		nMessage.show();
	}
	// En iOS
	else
	{
		// Creamos la vista y el label de alerta
		var lAlert = Titanium.UI.createLabel({ text:sMessage, font:{ fontSize:15, fontWeight:'regular' }, color:'#ffffff', width:'auto', height:'auto' });
		var aAux = lAlert.toImage();
		var vAlert = Titanium.UI.createView({ backgroundImage:getImage( 'navbar.png' ), width:aAux.width + 20, height:aAux.height + 10, top:(Titanium.Platform.displayCaps.platformHeight / 3) * 2, borderWidth:1, borderRadius:5, borderColor:'#dddddd' });
		Titanium.UI.currentWindow.add( vAlert );
		vAlert.add( lAlert );

		// Ocultamos la vista con una animación y la liberamos
		setTimeout( function(){ vAlert.animate({ opacity:0, duration:1000 }, function(){ Titanium.UI.currentWindow.remove( vAlert ); Titanium.UI.currentWindow.fireEvent( 'focus' ); }); }, 1000 );
	}
}

function showButton(sText, aOptions, fClick)
{
	// Cálculo de tamaños //

	var nWidth = Titanium.Platform.displayCaps.platformWidth;
	var nHeight = Titanium.Platform.displayCaps.platformHeight;

	// Botón //

	// Obtenemos el texto del botón
	sText = (sText.length > 10 ? sText.substring( 0, 7 ) + '...' : sText);

	// Obtenemos las opciones
	aOptions.width = 'auto';
	aOptions.height = nHeight * 0.0625;
	aOptions.backgroundColor = 'transparent';

	// Creamos la vista contenedor
	var vButton = Titanium.UI.createView( aOptions );

	// Si estamos en iOS
	if( ! Titanium.App.isAndroid )
	{
		// Creamos el label auxiliar para calcular el tamaño del botón
		var iAux = Titanium.UI.createLabel({ text:sText, font:{fontFamily:'Helvetica Neue', fontSize:nWidth * 0.0375, fontWeight:'bold'}, textAlign:Titanium.UI.TEXT_ALIGNMENT_CENTER, width:'auto', height:vButton.height });
		iAux = iAux.toImage();
		var nLabelWidth = iAux.width;
	}
	// Si estamos en Android
	else
		// El ancho es fijo a 100
		var nLabelWidth = wPer( 120 );

	// Flecha izquierda
	var iLeft = Titanium.UI.createImageView({ image:getImage( 'button_left_off.png' ), left:0, top:0, width:nWidth * 0.015625, height:vButton.height });
	vButton.add( iLeft );
	// Centro
	var iCenter = Titanium.UI.createLabel({ text:sText, font:{fontFamily:'Helvetica Neue', fontSize:nWidth * 0.0375, fontWeight:'bold'}, color:'#ffffff', textAlign:Titanium.UI.TEXT_ALIGNMENT_CENTER, left:iLeft.width, top:0, width:nLabelWidth, height:vButton.height, backgroundImage:getImage( 'button_center_off.png' ) });
	vButton.add( iCenter );
	// Borde derecho
	var iRight = Titanium.UI.createImageView({ image:getImage( 'button_right_off.png' ), left:iCenter.left + iCenter.width, top:0, width:nWidth * 0.015625, height:vButton.height });
	vButton.add( iRight );

	// Establecemos el ancho del contenedor
	vButton.width = iLeft.width + iCenter.width + iRight.width;

	// Evento cuando pulsamos sobre el botón de volver
	iLeft.addEventListener( 'touchstart', function(e){ touch( 'on' ); } );
	iCenter.addEventListener( 'touchstart', function(e){ touch( 'on' ); } );
	iRight.addEventListener( 'touchstart', function(e){ touch( 'on' ); } );
	// Evento cuando soltamos el botón de volver
	iLeft.addEventListener( 'touchend', function(e){ touch( 'off' ); } );
	iCenter.addEventListener( 'touchend', function(e){ touch( 'off' ); } );
	iRight.addEventListener( 'touchend', function(e){ touch( 'off' ); } );
	// Evento cuando hacemos click en el botón de volver
	iLeft.addEventListener( 'singletap', function(e){ fClick( vButton ); } );
	iCenter.addEventListener( 'singletap', function(e){ fClick( vButton ); } );
	iRight.addEventListener( 'singletap', function(e){ fClick( vButton ); } );

	// Función para cambiar las imágenes del botón
	function touch(sPos)
	{
		// Obtenemos las imágenes del botón
		sLeft = getImage( 'button_left_' + sPos + '.png' );
		sCenter = getImage( 'button_center_' + sPos + '.png' );
		sRight = getImage( 'button_right_' + sPos + '.png' );

		// Cambiamos las imágenes
		iLeft.image = sLeft;
		iCenter.backgroundImage = sCenter;
		iRight.image = sRight;
	}

	// Retornamos el backbutton
	return vButton;
}

function replaceAll(sText, sSearch, sReplace)
{
	while( sText.toString().indexOf( sSearch ) != -1 )
		sText = sText.toString().replace( sSearch, sReplace );
	return sText;
}