/**
 * Función que devuelve una imágen según la resolución. 
 *
 * Parámetros:
 * 	string sImage
 *
 */
var getImage = function(sImage)
{
	// Obtenemos la densidad de pantalla
	//var sDensity = getDensity();
	var sDensity = 'mdpi';

	// Retornamos la imágen según la densidad
	if( Titanium.Filesystem.getFile( Titanium.Filesystem.resourcesDirectory, 'themes/' + Titanium.App.theme + '/images/gui/' + sDensity + '/' + sImage ).exists() )
		return '/themes/' + Titanium.App.theme + '/images/gui/' + sDensity + '/' + sImage;
	// Si no existe retornamos false
	else
		return '';
}

/**
 * Función que devuelve la densidad de pantalla según la resolución.
 *
 * return
 * 	string
 * 
 */
var getDensity = function()
{
	// Variables
	var nWidth = Titanium.Platform.displayCaps.platformWidth;

	// Obtenemos la densidad según la resolución
	if( nWidth < 1024 )
		return 'mdpi';
	if( nWidth >= 1024 )
		return 'hdpi';
}

var getImageRemote = function(aOptions)
{
	// Construimos el nombre de la imagen resultante

	// Obtenemos la URL
	var sURL = aOptions.url;

	// Obtenemos el nombre del archivo en la URL
	var aURLName = sURL.match( /[\w_.-]*?(?=\?)|[\w_.-]*$/ );
	aURLName = aURLName[0];

	// Obtenemos la extensión del archivo en la URL
	var aURLExt = sURL.match( /[\w]*?(?=\?)|[\w]*$/ );
	aURLName = aURLName.replace( '.' + aURLExt[0], '' );

	// Obtenemos los parámetros de la URL
	var aURLParams = sURL.match( /(?:=)[^&]*/g );

	// Añadimos los parámetros al nombre del archivo
	for( var nCont = 0; nCont < aURLParams.length; nCont++ )
		aURLName = aURLName + '_' + aURLParams[nCont].replace( '=', '' );

	// Añadimos la extensión al fichero
	sName = aURLName + '.png';

	/* Obtenemos la imágen */

	// Obtenemos la imagen
	var sPath = '/cache/' + sName;
  	var sFile = Titanium.Filesystem.getFile( Titanium.Filesystem.resourcesDirectory, sPath );      

	// Si la imágen ya existe la retornamos con el callback
	if( sFile.exists() )
    	aOptions.callback( sPath, aOptions.source );
    // Si la imágen no existe la descargamos
    else
    {
		// Creamos el HTTPCliente
	    var hClient = Titanium.Network.createHTTPClient();
		hClient.setTimeout( 30000 );

 		// Evento que se lanza cuando se termina de descargar la imágen
		hClient.onload = function()
		{
			// Obtenemos la imágen remota
			var sRemote = this.responseData;

			// Si la imágen no se ha descargado correctamente
			if( ! sRemote )
				sPath = aOptions.defaultImage;
			// Si se ha descargado correctamente la imágen
			else
			{
				// Creamos una imageView auxiliar
				var iAux = Ti.UI.createImageView({ image:sRemote, width:'auto', height:'auto' });

				// Lo convertimos a blob
				var iImage = iAux.toImage();
				// Grabamos la imágen en la ruta
      			sFile.write( iImage );
			}

			// Llamamos al callback con la imágen resultado
			aOptions.callback( iImage, aOptions.source );
		};

 		// Evento que se lanza cuando hay un error al descargar la imágen
		hClient.onerror = function(e)
		{
			// Lanzamos el callback con la imágen por defecto
			aOptions.callback( aOptions.defaultImage, aOptions.source );
		};

		// Lanzamos la petición de la imágen 
		hClient.open( 'GET', sURL );
		hClient.send();
	}
}