Titanium.include( 'database.js' );
Titanium.include( '/functions/app.js' );
Titanium.include( '/functions/array.js' );
Titanium.include( '/functions/css.js' );
Titanium.include( '/functions/currencies.js' );
Titanium.include( '/functions/images.js' );
Titanium.include( '/functions/location.js' );
Titanium.include( '/functions/share.js' );
Titanium.include( '/classes/topbar.class.js' );
Titanium.include( '/classes/saves.class.js' );

// Variables globales //

// Variable que contendrá los productos
var aProducts = [];
// Tabla de productos
var tTable = undefined;
// Vista de botones de ordenación
var vOrder = undefined;
// Label de información
var wInformation = undefined;

// Botones de filtro
var bAlphabetical = null;
var bPrice = null;
var bNews = null;
var bAvailability = null;
var bOffers = null;
var bFreeShipping = null;
// Barra de tareas
var vTasks = undefined;

// Variable para conocer el tipo de ordenación actual
var sOrder = 'alphabetical';

// Variable de salvado de datos
var aSaves = null;

// Forzamos el color de fondo
Titanium.UI.currentWindow.backgroundColor = '#ffffff';

/* Top Bar */

// Mostramos el TopBar
var aTopBar = new topBar({
	backButton:Titanium.UI.currentWindow.type != 'favorites',
	showSearchButton:(Titanium.UI.currentWindow.type != 'search' && Titanium.UI.currentWindow.type != 'favorites'),
	editButton:Titanium.UI.currentWindow.type == 'favorites'
});
aTopBar.show();

// Función para lanzar la consulta inicial
function launchQuery(fCallback, nLimit)
{
	// Según el tipo de la ventana que lo llama lanzamos una consulta u otra
	switch( Titanium.UI.currentWindow.type )
	{
		// Ventana de productos por categoría
		case 'products':
			query({ query:'getProductsByCategory', data:{ idcategory:Titanium.UI.currentWindow.id, userid:(Titanium.App.User == undefined ? false : Titanium.App.User.userid), language:Titanium.App.idlanguage }, callback:fCallback });
			break;
		// Ventana de búsqueda
		case 'search':
			query({ query:'getProductsBySearch', data:{ search:Titanium.UI.currentWindow.value, userid:(Titanium.App.User == undefined ? false : Titanium.App.User.userid), language:Titanium.App.idlanguage }, callback:fCallback });
			break;
		// Novedades
		case 'newness':
			query({ query:'getNewness', data:{ quantity:Titanium.App.newness_quantity, userid:(Titanium.App.User == undefined ? false : Titanium.App.User.userid), language:Titanium.App.idlanguage }, callback:fCallback });
			break;
		// Ofertas
		case 'offers':
			query({ query:'getOffers', data:{ quantity:Titanium.App.offers_quantity, userid:(Titanium.App.User == undefined ? false : Titanium.App.User.userid), language:Titanium.App.idlanguage }, callback:fCallback });
			break;
		// Próximamente
		case 'comingsoon':
			query({ query:'getComingSoon', data:{ userid:(Titanium.App.User == undefined ? false : Titanium.App.User.userid), language:Titanium.App.idlanguage }, callback:fCallback });
			break;
		// Favoritos
		case 'favorites':
			// Mostramos los datos cuando hacemos foco
			Titanium.UI.currentWindow.addEventListener( 'focus', function(e)
				{
					// Inicializamos el array de productos
					aProducts = [];

					// Nueva instancia de saves
					aSaves = new Saves( 'favorites' );

					// Obtenemos el archivo
					var aFile = Titanium.Filesystem.getFile( Titanium.Filesystem.applicationDataDirectory, Titanium.UI.currentWindow.type + '.txt' );

					// Obtenemos los productos
					query({ query:'getProductsByID', data:{ ids:(aFile.exists() ? aFile.read().text : '[]'), userid:(Titanium.App.User == undefined ? false : Titanium.App.User.userid), language:Titanium.App.idlanguage }, callback:fCallback });
				}
			);
			break;
	}
}

// Lanzamos la consulta inicial
launchQuery( productsList, 0 );

function productsList(aResult)
{
	// Si obtenemos un resultado correcto
	if( aResult !== false )
	{
		// Si hay productos los mostramos
		if( aResult.length > 0 )
		{
			/* Cálculo de tamaños */

			var nWidth = Titanium.Platform.displayCaps.platformWidth;
			var nHeight = Titanium.Platform.displayCaps.platformHeight;

			// Calculamos el ancho y alto según la densidad
			if( Titanium.Platform.osname == 'android' )
			{
				// Ancho y alto según densidad
				nWidth = ( nWidth / ( Titanium.Platform.displayCaps.dpi / 160 ) );
				nHeight = ( nHeight / ( Titanium.Platform.displayCaps.dpi / 160 ) );
			}

			var nOrderBarSize = nHeight * 0.092;
			var nOrderButtonHeight = nHeight * 0.0625;
			var nOrderButtonWidth = (Titanium.Platform.osname == 'ipad' ? 'auto' : nWidth * 0.1484375);
			var nTasksSize = nHeight * 0.092;
			var nTasksButtonWidth = nWidth * 0.89375;
			var nTasksButtonHeight = nWidth * 0.096875;

			/* Productos */

			// Establecemos que la variable de productos contenga el resultado con los resultados formateados
			for( nCont = 0; nCont < aResult.length; nCont++ )
			{
				// Añadimos el registro al array de productos
				aProducts[nCont] = aResult[nCont];

				// Comprobamos si el producto está en oferta
				aProducts[nCont]['offer'] = (aResult[nCont].price_offer != null);

				// Si tenemos un precio de grupo lo cambiamos al precio
				if( aResult[nCont].price_group != null )
					aResult[nCont].price = aResult[nCont].price_group;

				/* Calculo de precio */

				// Obtenemos el precio original y el precio en oferta
				fPrice = aResult[nCont].price;
				fPriceOffer = aResult[nCont].price_offer;

				// Guardamos los precios
				aProducts[nCont]['price'] = getPriceFormatted( (aProducts[nCont].offer ? fPriceOffer : fPrice), aResult[nCont].tax );
				aProducts[nCont]['price_offer'] = getPriceFormatted( (aProducts[nCont].offer ? fPrice : false), aResult[nCont].tax );
				aProducts[nCont]['price_float'] = parseFloat( (aProducts[nCont].offer ? fPriceOffer : fPrice) );
			}

			// Barra de Filtro //

			// Creamos la barra superior de los botones de filtro
			vOrder = Titanium.UI.createView({ left:0, top:Titanium.App.top, width:nWidth, height:nOrderBarSize, eremove:true, backgroundColor:'transparent' });
			css( vOrder, 'products_order_bar' );
			Titanium.UI.currentWindow.add( vOrder );

			// Contenedor para los botones de filtro
			vFilterButtons = Titanium.UI.createView({ width:nOrderButtonWidth * 6, height:nOrderButtonHeight, layout:'horizontal', backgroundColor:'transparent' });

			// Botones de filtro
			bAlphabetical = Titanium.UI.createImageView({ image:getImage( 'filter_alphabetical_on.png' ), left:0, top:0, width:nOrderButtonWidth, height:vFilterButtons.height });
			vFilterButtons.add( bAlphabetical );
			bPrice = Titanium.UI.createImageView({ image:getImage( 'filter_price_off.png' ), left:0, top:0, width:nOrderButtonWidth, height:vFilterButtons.height });
			vFilterButtons.add( bPrice );
			bNews = Titanium.UI.createImageView({ image:getImage( 'filter_news_off.png' ), left:0, top:0, width:nOrderButtonWidth, height:vFilterButtons.height });
			vFilterButtons.add( bNews );
			bAvailability = Titanium.UI.createImageView({ image:getImage( 'filter_availability_off.png' ), left:0, top:0, width:nOrderButtonWidth, height:vFilterButtons.height });
			vFilterButtons.add( bAvailability );
			bOffers = Titanium.UI.createImageView({ image:getImage( 'filter_offers_off.png' ), left:0, top:0, width:nOrderButtonWidth, height:vFilterButtons.height });
			vFilterButtons.add( bOffers );
			bFreeShipping = Titanium.UI.createImageView({ image:getImage( 'filter_freeshipping_off.png' ), left:0, top:0, width:nOrderButtonWidth, height:vFilterButtons.height });
			vFilterButtons.add( bFreeShipping );

			// Posicionamos los botones de filtro
			vFilterButtons.left = (nWidth / 2) - (vFilterButtons.width / 2);
			vFilterButtons.top = (vOrder.height / 2) - (vFilterButtons.height / 2);

			vOrder.add( vFilterButtons );

			// Evento cuando hacemos click en el botón de ordenar alfabéticamente
			bAlphabetical.addEventListener('click', function(e)
			{
				// Llamamos a la función para crear el listado de productos
				if( sOrder != 'alphabetical' )
				{
					// Cambiamos la imagen del filtro
					filterImageChange( sOrder, 'alphabetical' );
					// Establecemos el tipo de ordenación
					sOrder = 'alphabetical';
					// Mostramos los productos
					products( aProducts );
				}
			});

			// Evento cuando hacemos click en el botón de ordenar por precio
			bPrice.addEventListener('click', function(e)
			{
				// Llamamos a la función para crear el listado de productos con el array ordenado
				if( sOrder != 'price' )
				{
					// Cambiamos la imagen del filtro
					filterImageChange( sOrder, 'price' );
					// Establecemos el tipo de ordenación
					sOrder = 'price';
					// Mostramos los productos
					products( arrayOrder( 'price_float', 'ASC' ) );
				}
			});

			// Evento cuando hacemos click en el botón de ordenar por novedad
			bNews.addEventListener('click', function(e)
			{
				// Llamamos a la función para crear el listado de productos con el array ordenado
				if( sOrder != 'news' )
				{
					// Cambiamos la imagen del filtro
					filterImageChange( sOrder, 'news' );
					// Establecemos el tipo de ordenación
					sOrder = 'news';
					// Mostramos los productos
					products( arrayOrder( 'date', 'DESC' ) );
				}
			});

			// Evento cuando hacemos click en el botón de ordenar por disponibilidad
			bAvailability.addEventListener('click', function(e)
			{
				// Llamamos a la función para crear el listado de productos con el array ordenado
				if( sOrder != 'availability' )
				{
					// Variable de productos disponibles
					var aAvailability = [];
					// Variable para productos disponibles
					var nCont2 = 0;

					// Eliminamos los productos no disponibles
					for( nCont = 0; nCont < aProducts.length; nCont++ )
					{
						// Si está el producto disponible lo añadimos
						//if( aProducts[nCont].quantity > 0 )
						{
							// Añadimos el producto disponible
							aAvailability[nCont2] = aProducts[nCont];
							nCont2++;
						}
					}

					// Cambiamos la imagen del filtro
					filterImageChange( sOrder, 'availability' );
					// Establecemos el tipo de ordenación
					sOrder = 'availability';
					// Mostramos los productos
					products( aAvailability );
				}
			});

			// Evento cuando hacemos click en el botón de ordenar por ofertas
			bOffers.addEventListener('click', function(e)
			{
				// Llamamos a la función para crear el listado de productos con el array ordenado
				if( sOrder != 'offers' )
				{
					// Variable de productos en oferta
					var aOffers = [];
					// Variable para productos en oferta
					var nCont2 = 0;

					// Eliminamos los productos no en oferta
					for( nCont = 0; nCont < aProducts.length; nCont++ )
					{
						// Si está el producto en oferta lo añadimos
						if( aProducts[nCont].offer )
						{
							// Añadimos el producto en oferta
							aOffers[nCont2] = aProducts[nCont];
							nCont2++;
						}
					}

					// Cambiamos la imagen del filtro
					filterImageChange( sOrder, 'offers' );
					// Establecemos el tipo de ordenación
					sOrder = 'offers';
					// Mostramos los productos
					products( aOffers );
				}
			});

			// Evento cuando hacemos click en el botón de ordenar por envio gratuito
			if( Titanium.App.filter_freeshipping )
			{
				bFreeShipping.addEventListener('click', function(e)
				{
					// Llamamos a la función para crear el listado de productos con el array ordenado
					if( sOrder != 'freeshipping' )
					{
						// Variable de productos con envío gratuito
						var aFreeShipping = [];
						// Variable para productos con envío gratuito
						var nCont2 = 0;

						// Eliminamos los productos sin envío gratuito
						for( nCont = 0; nCont < aProducts.length; nCont++ )
						{
							// Si está el producto en oferta lo añadimos
							if( aProducts[nCont].freeshipping == 1 )
							{
								// Añadimos el producto con envío gratuito
								aFreeShipping[nCont2] = aProducts[nCont];
								nCont2++;
							}
						}

						// Cambiamos la imagen del filtro
						filterImageChange( sOrder, 'freeshipping' );
						// Establecemos el tipo de ordenación
						sOrder = 'freeshipping';
						// Mostramos los productos
						products( aFreeShipping );
					}
				});
			}

			/* Barra de tareas */

			// Si estamos en favoritos creamos la barra de tareas
			if( Titanium.UI.currentWindow.type == 'favorites' )
			{
				// Creamos la vista para contener los botones de ordenación
				vTasks = Titanium.UI.createView({ left:0, bottom:Titanium.App.bottom, width:nWidth, height:nTasksSize, backgroundColor:'transparent', eremove:true });
				css( vTasks, 'products_order_bar' );

				// Botones de mapa
				var bTransfer = Titanium.UI.createLabel({ text:'  '+ getLocatedString( 'text_atcart' ), textAlign:Titanium.UI.TEXT_ALIGNMENT_LEFT, font:{ fontSize:nWidth * 0.0406, fontWeight:'regular' }, color:'#ddc559', backgroundImage:getImage( 'favorites_atcart.png' ), width:nWidth * 0.29687, height:nTasksButtonHeight, left:(nWidth / 2) - (nTasksButtonWidth / 2) });
				vTasks.add( bTransfer );
				var bEmpty = Titanium.UI.createLabel({ text:'    ' + getLocatedString( 'text_empty' ), textAlign:Titanium.UI.TEXT_ALIGNMENT_LEFT, font:{ fontSize:nWidth * 0.0406, fontWeight:'regular' }, color:'#ddc559', backgroundImage:getImage( 'favorites_empty.png' ), width:nWidth * 0.26562, height:nTasksButtonHeight, left:bTransfer.left + bTransfer.width });
				vTasks.add( bEmpty );
				var bShare = Titanium.UI.createLabel({ text:'    ' + getLocatedString( 'text_share' ), textAlign:Titanium.UI.TEXT_ALIGNMENT_LEFT, font:{ fontSize:nWidth * 0.0406, fontWeight:'regular' }, color:'#ddc559', backgroundImage:getImage( 'favorites_share.png' ), width:nWidth * 0.33125, height:nTasksButtonHeight, left:bEmpty.left + bEmpty.width });
				vTasks.add( bShare );
				Titanium.UI.currentWindow.add( vTasks );

				// Evento cuando hacemos click en el botón de transferir
				bTransfer.addEventListener('click', function(e)
				{
					// Creamos una ventana de diálogo con opciones para confirmar la transferencia
					var dDialog = Titanium.UI.createOptionDialog({ title:getLocatedString( 'message_atcart' ), options:[getLocatedString( 'text_yes' ), getLocatedString( 'text_no' )], destructive:1 });

					// Mostramos las opciones
					dDialog.show();

					// Evento que se lanza cuando se clica sobre alguna de las opciones del diálogo
					dDialog.addEventListener( 'click', function(e)
					{
						// Si clicamos en "Si"
					    if( e.index == 0 )
					    {
							// Nueva instancia de saves
							aSaves = new Saves( 'cart' );

							// Transferimos los favoritos al carrito
							aSaves.transfer();

							// Vaciamos el registro de productos
							// aProducts = [];

							// Damos foco para refrescar
							Titanium.UI.currentWindow.fireEvent( 'focus' );
					    }
					});
				});

				// Evento cuando hacemos click en el botón de vaciar
				bEmpty.addEventListener('click', function(e)
				{
					// Creamos una ventana de diálogo con opciones para confirmar el vaciado
					var dDialog = Titanium.UI.createOptionDialog({ title:getLocatedString( 'message_empty_favorites' ), options:[getLocatedString( 'text_yes' ), getLocatedString( 'text_no' )], destructive:1 });

					// Mostramos las opciones
					dDialog.show();

					// Evento que se lanza cuando se clica sobre alguna de las opciones del diálogo
					dDialog.addEventListener( 'click', function(e)
					{
						// Si clicamos en "Si"
					    if( e.index == 0 )
					    {
							// Vaciamos el registro de productos
							aProducts = [];

							// Vaciamos el archivo
							aSaves.deleteFile();

							// Damos foco para refrescar
							Titanium.UI.currentWindow.fireEvent( 'focus' );
					    }
					});
				});

				// Evento cuando hacemos click en el botón de compartir
				bShare.addEventListener('click', function(e)
				{
					// Creamos una ventana de diálogo con opciones para compartir
					var dDialog = Titanium.UI.createOptionDialog({ title:getLocatedString( 'window_share' ), options:['Facebook', 'Twitter', getLocatedString( 'text_cancel' )], destructive:2 });

					// Mostramos las opciones
					dDialog.show();

					// Evento que se lanza cuando se clica sobre alguna de las opciones del diálogo
					dDialog.addEventListener( 'click', function(e)
					{
						// Componemos los productos
						var sShare = '';

						// Recorremos los productos
				    	for( nCont = 0; nCont < aResult.length; nCont++ )
				    		sShare = sShare + aResult[nCont].product + ' ' + Titanium.App.server + aResult[nCont].idproduct + '-' + replaceAll( replaceAll( aResult[nCont].product.trim().toLowerCase(), ' ', '-' ), '--', '-' ) + '.html' + "\n";

						// Facebook
					    if( e.index == 0 )
					    {
					    	// Compartir en Facebook
					    	shareFacebook(
					    	{
					    		message: 'Quiero compartir contigo mi lista de favoritos de la tienda ' + Titanium.App.store_name + ':\n\n' + sShare,
					    		dialog: false
					    	});
					    }
					    // Twitter
					    else if( e.index == 1 )
					    {
					    	// Compartir en Twitter
					    	shareTwitter(
					    	{
					    		message: 'Mis favoritos de ' + Titanium.App.store_name + ': ' + sShare,
					    		dialog: false
					    	});
					    }
					});
				});
			}

			// Llamamos a la función para crear el listado de productos
			products( aProducts );
		}
		// Si no hay productos mostramos mensaje de información
		else
		{
			// Variables
			sText = '';

			// Eliminamos la tabla de datos anterior
			if( tTable != undefined )
			{
				Titanium.UI.currentWindow.remove( tTable );
				tTable = undefined;
			}
			// Eliminamos la vista de ordenacion
			if( vOrder != undefined )
			{
				Titanium.UI.currentWindow.remove( vOrder );
				vOrder = undefined;
			}
			// Eliminamos la vista de la barra de tareas
			if( vTasks != undefined )
			{
				Titanium.UI.currentWindow.remove( vTasks );
				vTasks = undefined;
			}

			// Eliminamos los elementos sobrantes
			for( nCont = 0; nCont < Titanium.UI.currentWindow.children.length; nCont++ )
			{
				// Si tenemos la propiedad eRemove, quiere decir que quiere ser eliminado
				if( Titanium.UI.currentWindow.children[nCont].eremove )
					Titanium.UI.currentWindow.remove( Titanium.UI.currentWindow.children[nCont] );
			}

			// Mostramos el fondo vacio
			Titanium.UI.currentWindow.backgroundImage = getImage( 'empty.png' );

			// Obtenemos el texto informativo
			switch( Titanium.UI.currentWindow.type )
			{
				case 'products': sText = getLocatedString( 'message_no_products_category' ); break;
				case 'search': sText = getLocatedString( 'message_no_search' ) + ' "' + Titanium.UI.currentWindow.value + '".'; break;
				case 'newness': sText = getLocatedString( 'message_no_newness' ); break;
				case 'offers': sText = getLocatedString( 'message_no_offers' ); break;
				case 'comingsoon': sText = getLocatedString( 'message_no_comingsoon' ); break;
				case 'favorites': sText = getLocatedString( 'message_no_favorites' ); break;
			}

			// Contenedor de información
			wInformation = Titanium.UI.createView({ left:10, right:10, top:Titanium.App.top + (nOrderBarSize ? nOrderBarSize : 0) + hPer( 100 ), bottom:Titanium.App.bottom + (vTasks == undefined ? 0 : vTasks.height), layout:'vertical' });
			Titanium.UI.currentWindow.add( wInformation );
			// Creamos el label de información
			var lInformation = Titanium.UI.createLabel({ text:sText, top:0, font:{ fontSize:wPer( 45 ), fontWeight:'bold' }, shadowOffset:{x:3, y:3}, textAlign:'center' });
			css( lInformation, 'products_empty_information' );
			wInformation.add( lInformation );
			// Creamos el label de información extra
			var lInformationExtra = Titanium.UI.createLabel({ text:getLocatedString( 'message_no_extra' ), font:{ fontSize:wPer( 45 ), fontWeight:'bold' }, shadowOffset:{x:3, y:3}, textAlign:'center' });
			css( lInformationExtra, 'products_empty_information_extra' );
			wInformation.add( lInformationExtra );
		}
	}
}

function products(aOrders)
{
	Titanium.include( '/functions/css.js' );

	/* Mensaje de carga */

	// Creamos el mensaje de carga
	if( tTable != undefined )
	{
		var aLoading = Titanium.UI.createActivityIndicator();

		if( Titanium.App.isAndroid )
			aLoading.message = 'Ordenando...';
		else
			 aLoading.style = Titanium.UI.iPhone.ActivityIndicatorStyle.PLAIN;
		Titanium.UI.currentWindow.add( aLoading );
		aLoading.show();
	}

	/* Cálculo de tamaños */

	var nWidth = Titanium.Platform.displayCaps.platformWidth;
	var nHeight = Titanium.Platform.displayCaps.platformHeight;

	// Calculamos el ancho y alto según la densidad
	if( Titanium.Platform.osname == 'android' )
	{
		// Ancho y alto según densidad
		nWidth = ( nWidth / ( Titanium.Platform.displayCaps.dpi / 160 ) );
		nHeight = ( nHeight / ( Titanium.Platform.displayCaps.dpi / 160 ) );
	}

	var nOrderBarSize = nHeight * 0.092;
	var nRowSize = (nHeight - Titanium.App.topBarSize - Titanium.App.tabGroupSize - nOrderBarSize) / 3.4;

	/* Productos */

	// Eliminamos la tabla de datos anterior
	if( tTable != undefined )
	{
		Titanium.UI.currentWindow.remove( tTable );
		tTable = undefined;
	}
	// Eliminamos el mensaje de información anterior
	if( wInformation != undefined )
	{
		Titanium.UI.currentWindow.remove( wInformation );
		wInformation = undefined;
	}

	// Si hay productos los mostramos
	if( aOrders.length > 0 )
	{
		// Mostramos el fondo
		Titanium.UI.currentWindow.backgroundImage = getImage( 'background.png' );

		// Creamos la tabla para mostrar los productos
		tTable = Titanium.UI.createTableView({ top:Titanium.App.top + nOrderBarSize, bottom:Titanium.App.bottom + (vTasks == undefined ? 0 : vTasks.height), backgroundColor:'#FFFFFF', allowsSelection:true, allowsSelectionDuringEditing:false, editable:Titanium.UI.currentWindow.type == 'favorites', deleteButtonTitle:getLocatedString( 'button_delete' ), eremove:true });

		// Le ponemos el fondo con imagen si es de favoritos
		if( Titanium.UI.currentWindow.type == 'favorites' )
			tTable.backgroundImage = getImage( 'background-cart.png' );
		
		// Array de datos
		var aData = [];

		// Recorremos el resultado y lo añadimos a la tabla
		for( nCont = 0; nCont < aOrders.length; nCont++ )
		{
			// Si es la fila de contador
			if( aOrders[nCont].count != undefined && aOrders[nCont].count > 0 )
			{
				// Creamos la fila para recargar
				var aRow = Titanium.UI.createTableViewRow({ height:nRowSize / 2, className:'load', backgroundColor:'#ffffff', selectedBackgroundColor:'#fed631', borderColor:'#cccccc' });
				// Creamos el label del titulo
				var lTitle = Titanium.UI.createLabel({ text:'   Ver más productos...', font:{ fontSize:nRowSize / 6, fontWeight:'regular' }, color:'#444444', top:0, left:0, right:0, bottom:0, textAlign:'left' });
				aRow.add( lTitle );

				continue;
			}

			// Creamos la fila
			var aRow = Titanium.UI.createTableViewRow({ id:aOrders[nCont].idproduct, text:aOrders[nCont].product, height:nRowSize, className:'products', backgroundColor:(Titanium.UI.currentWindow.type == 'favorites' ? '#fffcee' : '#ffffff'), selectedBackgroundColor:'#f7e38b', borderColor:'#cccccc', hasChild: ! aOrders[nCont].offer });

			// Obtenemos la URL de la imagen
			var sImage = (aOrders[nCont].image != '' && aOrders[nCont].image != null ? Titanium.App.images + 'img/p/' + aOrders[nCont].image.split( '' ).join( '/' ) + '/' + aOrders[nCont].image + '-home.jpg' : '');

			// Creamos la imagen izquierda
			var iImage =  Titanium.UI.createImageView({ image:encodeURI( sImage ), width:nRowSize - 4, height:nRowSize - 4, top:2, left:2, backgroundColor:'transparent', hires:true });
			aRow.add( iImage );
			// Creamos la linea decorativa
			aRow.add( Titanium.UI.createView({ top:0, left:nRowSize, bottom:0, width:1, backgroundColor:'#cccccc' }) );
			// Creamos el label del titulo
			var lTitle = Titanium.UI.createLabel({ text:(aOrders[nCont].product.length > 90 ? aOrders[nCont].product.substr( 0, 87 ) + '...' : aOrders[nCont].product ), minimumFontSize:2, font:{ fontSize:aRow.height / 8, fontWeight:'bold', fontFamily:'Helvetica Neue' }, color:(! aOrders[nCont].offer ? '#000000' : '#e8132c'), top:5, bottom:(nRowSize / 2) - 5, left:nRowSize + 15, right:(aOrders[nCont].price_offer ? 48 : 0), textAlign:'left' });
			//css( lTitle, 'products_table_row_title' + (aOrders[nCont].offer ? '_offer' : '') );
			aRow.add( lTitle );
			// Mostramos el precio
			var aPrice = showPrice( { price:aOrders[nCont].price, fontSize:nWidth * 0.078125, left:lTitle.left, top:(nRowSize / 2) + 3, width:nWidth - lTitle.left, height:nRowSize - ((nRowSize / 2) + 3), color:'#000000', offer:aOrders[nCont].price_offer } )
			aRow.add( aPrice );
			// Creamos la imagen del stock
			var iStock =  Titanium.UI.createImageView({ image:getStockImage( parseInt( aOrders[nCont].quantity ) ), width:wPer( 19 ), height:wPer( 19 ), bottom:5, left:lTitle.left });
			aRow.add( iStock );
			// Si el producto está en oferta creamos la imagen que indica la oferta
			if( aOrders[nCont].offer )
			{
				var aOfferImage = Titanium.UI.createImageView({ image:getImage( 'offer_product_' + Titanium.App.language + '.png' ), width:wPer( 71 ), height:wPer( 69 ), left:0, top:0 });
				aRow.add( aOfferImage );
			}
			// Creamos la vista superior
			var vTop = Titanium.UI.createView({ id:aOrders[nCont].idproduct, text:aOrders[nCont].product, left:0, right:0, top:0, bottom:0, backgroundColor:'transparent' });
			aRow.add( vTop );

			// Evento cuando hacemos click en un elemento de la lista
			vTop.addEventListener('click', function(e)
			{
				// Abrimos la ventana de detalle de producto
				var wProductDetail = Titanium.UI.createWindow({ id:e.source.id, title:e.source.text, backgroundColor:'#ffffff', url:'productdetail.js', windowParent:Titanium.UI.currentWindow, navBarHidden:true });

				// Abrimos la ventana
				openWindowInTab( wProductDetail );
			});

			// Si estamos en favoritos
			if( Titanium.UI.currentWindow.type == 'favorites' )
			{
				// Evento cuando hacemos un click largo en un elemento de la lista
				vTop.addEventListener('longclick', function(e)
				{
					// Obtenemos el id del registro
					var nID = e.source.id;

					// Creamos una ventana de diálogo con opciones
					var dDialog = Titanium.UI.createOptionDialog({ title:'Opciones', options:['Eliminar registro', 'Cancelar'], destructive:1 });

					// Mostramos las opciones
					dDialog.show();

					// Evento que se lanza cuando se clica sobre alguna de las opciones del diálogo
					dDialog.addEventListener( 'click', function(e)
					{
						// Si clicamos en "Eliminar"
					    if( e.index == 0 )
					    {
					    	// Creamos una nueva instancia del objeto saves
					    	var aSaves = new Saves( 'favorites' );

							// Eliminamos el elemento seleccionado del fichero
							aSaves.deleteRecord({ id:nID });

							// Hacemos foco para mostrar los productos
							Titanium.UI.currentWindow.fireEvent( 'focus' );
					    }
					});
				});
			}

			// Añadimos la fila a los datos
			aData.push( aRow );
		}

		// Añadimos los datos a la tabla
		tTable.setData( aData );

		// Pasamos al topBar la tabla para ser editada
		aTopBar.setTable( tTable );

		// Añadimos la tabla
		Titanium.UI.currentWindow.add( tTable );

		// Evento cuando eliminamos un elemento de la lista
		tTable.addEventListener('delete', function(e)
		{
			// Eliminamos el elemento seleccionado del fichero
			aSaves.deleteRecord({ id:e.rowData.id });

			// Si no hay productos informamos
			if( aSaves.recordCount() == 0 )
				Titanium.UI.currentWindow.fireEvent( 'focus' );
		});
	}
	// Si no hay productos informamos
	else
	{
		// Eliminamos la tabla de datos anterior
		if( tTable != undefined )
		{
			Titanium.UI.currentWindow.remove( tTable );
			tTable = undefined;
		}

		// Mostramos el fondo vacio
		Titanium.UI.currentWindow.backgroundImage = getImage( 'empty.png' );

		// Obtenemos el texto informativo
		switch( sOrder )
		{
			case 'availability': sText = getLocatedString( 'message_no_products_availables' ); break;
			case 'offers': sText = getLocatedString( 'message_no_offers' ); break;
			case 'freeshipping': sText = getLocatedString( 'message_no_freeshipping' ); break;
		}

		// Contenedor de información
		wInformation = Titanium.UI.createView({ left:10, right:10, top:Titanium.App.top + (nOrderBarSize ? nOrderBarSize : 0) + hPer( 100 ), bottom:Titanium.App.bottom + (vTasks == undefined ? 0 : vTasks.height), layout:'vertical' });
		Titanium.UI.currentWindow.add( wInformation );
		// Creamos el label de información
		var lInformation = Titanium.UI.createLabel({ text:sText, font:{ fontSize:wPer( 45 ), fontWeight:'bold' }, shadowOffset:{x:3, y:3}, textAlign:'center' });
		css( lInformation, 'products_empty_information' );
		wInformation.add( lInformation );
		// Creamos el label de información extra
		var lInformationExtra = Titanium.UI.createLabel({ text:getLocatedString( 'message_no_extra' ), font:{ fontSize:wPer( 45 ), fontWeight:'bold' }, shadowOffset:{x:3, y:3}, textAlign:'center' });
		css( lInformationExtra, 'products_empty_information_extra' );
		wInformation.add( lInformationExtra );
	}

	// Liberamos la ventana de carga
	if( aLoading != undefined )
	{
		aLoading.hide();
		Titanium.UI.currentWindow.remove( aLoading );
	}
}

function filterImageChange(sBeforeFilter, sAfterFilter)
{
	// Cambiamos la imagen a apagada
	switch( sBeforeFilter )
	{
		case 'alphabetical': bAlphabetical.image = getImage( 'filter_alphabetical_off.png' ); break;
		case 'price': bPrice.image = getImage( 'filter_price_off.png' ); break;
		case 'news': bNews.image = getImage( 'filter_news_off.png' ); break;
		case 'availability': bAvailability.image = getImage( 'filter_availability_off.png' ); break;
		case 'offers': bOffers.image = getImage( 'filter_offers_off.png' ); break;
		case 'freeshipping': bFreeShipping.image = getImage( 'filter_freeshipping_off.png' ); break;
	}

	// Cambiamos la imagen a encendida
	switch( sAfterFilter )
	{
		case 'alphabetical': bAlphabetical.image = getImage( 'filter_alphabetical_on.png' ); break;
		case 'price': bPrice.image = getImage( 'filter_price_on.png' ); break;
		case 'news': bNews.image = getImage( 'filter_news_on.png' ); break;
		case 'availability': bAvailability.image = getImage( 'filter_availability_on.png' ); break;
		case 'offers': bOffers.image = getImage( 'filter_offers_on.png' ); break;
		case 'freeshipping': bFreeShipping.image = getImage( 'filter_freeshipping_on.png' ); break;
	}
}